@@ -6,6 +6,8 @@ use std::{fs, env};
 use crate::binaries::platform::binary_platform_name;
 use crate::binaries::{fetch_engine, global_cache_dir};
 use std::path::Path;
+use std::fs::File;
+use std::io::Write;
 
 fn add_defaults(input: &mut Root) -> &mut Root {
     match input.generator.config.get("package") {
@@ -37,7 +39,12 @@ pub fn run(input: &mut Root) {
         fetch_engine(global_cache_dir(), "query-engine".to_string(), binary_name).unwrap();
     }
 
-    let file_path = env::current_dir().unwrap().join("prisma.rs");
-    fs::write( file_path, "FFFFFFFF".to_string()).unwrap();
+    let mut file = File::create(
+        env::current_dir()
+            .unwrap()
+            .join("prisma.rs")
+    ).expect("Failed to open file for codegen");
+
+    file.write("ABCD".as_bytes());
 }
 
